@@ -11,6 +11,9 @@
 #include <database.h>
 #include <mms.h>
 #include "modemcontroller.h"
+#include "ecurl.h"
+
+#include "qcorotask.h"
 
 constexpr std::array<QStringView, 6> TAPBACK_KEYS = { u"♥️", u"👍", u"👎", u"😂", u"‼️", u"❓" };
 constexpr std::array<QStringView, 6> TAPBACK_REMOVED = {
@@ -42,13 +45,18 @@ public:
     // QString argument since this needs to be called from DBus
     Q_SCRIPTABLE void disableNotificationsForNumber(const QString &numbers);
     Q_SCRIPTABLE void manualDownload(const QString &id, const QString &url, const QDateTime &expires);
+    Q_SCRIPTABLE void sendMessage(const QString &numbers, const QString &id, const QString &text, const QStringList &files, const qint64 &totalSize);
     Q_SCRIPTABLE void sendTapback(const QString &numbers, const QString &id, const QString &tapback, const bool &isRemoved);
     Q_SCRIPTABLE void syncSettings();
+    Q_SCRIPTABLE QString ownNumber();
+    Q_SCRIPTABLE QString countryCode();
 
 private:
     void checkMessages();
     void handleIncomingMessage(ModemManager::Sms::Ptr msg);
     void createDownloadNotification(const MmsMessage &mmsMessage);
+    void addMessage(const Message &message);
+    void updateMessage(const Message &message);
     void saveMessage(
         const PhoneNumberList &phoneNumberList,
         const QDateTime &datetime,
@@ -62,6 +70,15 @@ private:
         const QDateTime &expires = QDateTime(),
         const int size = 0
     );
+    QCoro::Task<QString> sendMessageSMS(const PhoneNumber &phoneNumber, const QString &id, const QString &text);
+    QCoro::Task<QString> sendMessageMMS(const PhoneNumberList &phoneNumberList, const QString &id, const QString &text, const QStringList &files, const qint64 totalSize);
+    QCoro::Task<void> sendCancelResponse(const QString &transactionId);
+    QCoro::Task<void> sendDeliveryAcknowledgement(const QString &transactionId);
+    QCoro::Task<void> sendNotifyResponse(const QString &transactionId, const QString &status);
+    QCoro::Task<void> sendReadReport(const QString &messageId);
+    QCoro::Task<QByteArray> uploadMessage(const QByteArray &data);
+    QCoro::Task<void> downloadMessage(const MmsMessage message);
+    void handleDownloadedMessage(const QByteArray &response, const QString &url, const QDateTime &expires);
     void createNotification(Message &message);
     bool handleTapbackReaction(Message &message, const QString &reactNumber);
     bool saveTapback(Message &message, const QString &reactNumber, const QStringView &tapback, std::span<const QStringView> list, const bool &isAdd, const bool &isImage);
@@ -70,6 +87,8 @@ private:
 
     Mms m_mms;
 
+    ECurl m_curl;
+
     PhoneNumberList m_disabledNotificationNumber;
 
     PhoneNumber m_ownNumber;
@@ -78,9 +97,6 @@ private:
 
     QStringList m_deferredIndicators;
 
-private Q_SLOTS:
-    void handleDownloadedMessage(const QByteArray &response, const QString &url, const QDateTime &expires);
-
 Q_SIGNALS:
     Q_SCRIPTABLE void messageAdded(const QString &phoneNumber, const QString &id);
     Q_SCRIPTABLE void messageUpdated(const QString &phoneNumber, const QString &id);
