@@ -5,6 +5,7 @@
 #include <QCommandLineParser>
 #include <QCoreApplication>
 
+#include <KDBusService>
 #include <KLocalizedString>
 
 #include "global.h"
@@ -26,10 +27,13 @@ int main(int argc, char *argv[])
     parser.addOption(modemOpt);
     parser.process(app);
 
+    KDBusService service(KDBusService::Unique);
+
     // Create observer
     auto modemPath = parser.isSet(modemOpt) && !parser.value(modemOpt).isEmpty()
             ? parser.value(modemOpt)
             : std::optional<QString>();
+
     ChannelLogger logger(modemPath);
 
     QCoreApplication::exec();
