@@ -17,13 +17,13 @@
 #include <global.h>
 
 constexpr auto ID_LEN = 10;
-constexpr auto DATABASE_REVISION = 7; // Keep MIGRATE_TO_LATEST_FROM in sync
+constexpr auto DATABASE_REVISION = 8; // Keep MIGRATE_TO_LATEST_FROM in sync
 #define MIGRATE_TO(n, current) \
     if (current < n) { \
         qDebug() << "Running migration" << #n; \
         migrationV##n(current); \
     }
-#define MIGRATE_TO_LATEST_FROM(current) MIGRATE_TO(7, current)
+#define MIGRATE_TO_LATEST_FROM(current) MIGRATE_TO(8, current)
 
 enum Column {
     IdColumn = 0,
@@ -61,11 +61,9 @@ Database::Database(QObject *parent)
     if (!open) {
         qWarning() << "Could not open messages database" << m_database.lastError();
     }
-
-    migrate();
 }
 
-QVector<Message> Database::messagesForNumber(const PhoneNumberList &phoneNumberList, const QString &id, const bool last) const
+QVector<Message> Database::messagesForNumber(const PhoneNumberList &phoneNumberList, const QString &id, const int limit) const
 {
     QVector<Message> messages;
 
@@ -90,17 +88,29 @@ QVector<Message> Database::messagesForNumber(const PhoneNumberList &phoneNumberL
             size,
             tapbacks
         FROM Messages
-        WHERE (phoneNumber == :phoneNumber AND :id IS NULL) OR id ==:id
-        ORDER BY time DESC
     )");
-    if (last) {
-        sql.append(SL(" LIMIT 1"));
+
+   QSqlQuery fetch(m_database);
+
+    if (id.isEmpty()) {
+        sql.append(SL("WHERE phoneNumber == :phoneNumber ORDER BY time DESC"));
+
+        if (limit == 0) {
+            sql.append(SL(" LIMIT 30"));
+        } else if (limit == 1) {
+            sql.append(SL(" LIMIT 1"));
+        } else {
+            sql.append(SL(" LIMIT -1 OFFSET 30"));
+        }
+
+        fetch.prepare(sql);
+        fetch.bindValue(SL(":phoneNumber"), phoneNumberList.toString());
+    } else {
+        sql.append(SL("WHERE id == :id"));
+        fetch.prepare(sql);
+        fetch.bindValue(SL(":id"), id);
     }
 
-    QSqlQuery fetch(m_database);
-    fetch.prepare(sql);
-    fetch.bindValue(SL(":phoneNumber"), phoneNumberList.toString());
-    fetch.bindValue(SL(":id"), id);
     exec(fetch);
 
     while (fetch.next()) {
@@ -206,35 +216,54 @@ QString Database::lastMessageWithAttachment(const PhoneNumberList &phoneNumberLi
     return fetch.value(0).toString();
 }
 
-QVector<Chat> Database::chats() const
+QVector<Chat> Database::chats(const PhoneNumberList &phoneNumberList) const
 {
     QVector<Chat> chats;
 
-    auto before = QTime::currentTime().msecsSinceStartOfDay();
-
-    QSqlQuery fetch(m_database);
-    fetch.prepare(SL("SELECT DISTINCT phoneNumber FROM Messages"));
-    exec(fetch);
-
-    while (fetch.next()) {
+    if (phoneNumberList.count() > 0) {
         Chat chat;
-        chat.phoneNumberList = PhoneNumberList(fetch.value(0).toString());
+        chat.phoneNumberList = phoneNumberList;
         chat.unreadMessages = unreadMessagesForNumber(chat.phoneNumberList);
 
-        QVector<Message> messages = messagesForNumber(chat.phoneNumberList, QString(), true);
+        QVector<Message> messages = messagesForNumber(chat.phoneNumberList, QString(), 1);
 
         if (messages.length() > 0) {
             chat.lastMessage = messages.at(0).text;
-            chat.lastContacted = messages.at(0).datetime;
+            chat.lastDateTime = messages.at(0).datetime;
             chat.lastSentByMe = messages.at(0).sentByMe;
             chat.lastAttachment = messages.at(0).attachments;
         }
 
         chats.append(chat);
-    }
+    } else {
+        auto before = QTime::currentTime().msecsSinceStartOfDay();
 
-    auto after = QTime::currentTime().msecsSinceStartOfDay();
-    qDebug() << "TOOK TIME" << after - before;
+        QSqlQuery fetch(m_database);
+
+        fetch.prepare(SL(R"(
+            WITH Numbers AS (
+                SELECT
+                    MAX(time) AS maxTime,
+                    phoneNumber
+                FROM Messages
+                GROUP BY phoneNumber
+            )
+            SELECT phoneNumber
+            FROM  Numbers
+            ORDER BY maxTime desc
+        )"));
+
+        exec(fetch);
+
+        while (fetch.next()) {
+            Chat chat;
+            chat.phoneNumberList = PhoneNumberList(fetch.value(0).toString());
+            chats.append(chat);
+        }
+
+        auto after = QTime::currentTime().msecsSinceStartOfDay();
+        qDebug() << "TOOK TIME" << after - before;
+    }
 
     return chats;
 }
@@ -256,8 +285,6 @@ void Database::markChatAsRead(const PhoneNumberList &phoneNumberList)
     update.prepare(SL("UPDATE Messages SET read = True WHERE phoneNumber = :phoneNumber AND NOT read == True"));
     update.bindValue(SL(":phoneNumber"), phoneNumberList.toString());
     exec(update);
-
-    Q_EMIT messagesChanged(phoneNumberList);
 }
 
 void Database::deleteChat(const PhoneNumberList &phoneNumberList)
@@ -266,8 +293,6 @@ void Database::deleteChat(const PhoneNumberList &phoneNumberList)
     update.prepare(SL("DELETE FROM Messages WHERE phoneNumber = :phoneNumber"));
     update.bindValue(SL(":phoneNumber"), phoneNumberList.toString());
     exec(update);
-
-    Q_EMIT messagesChanged(phoneNumberList);
 }
 
 void Database::addMessage(const Message &message)
@@ -331,8 +356,6 @@ void Database::addMessage(const Message &message)
     }
     putCall.bindValue(SL(":size"), message.size);
     exec(putCall);
-
-    Q_EMIT messagesChanged(message.phoneNumberList);
 }
 
 void Database::deleteMessage(const QString &id)
@@ -352,6 +375,34 @@ QString Database::generateRandomId()
     return intermediateId;
 }
 
+void Database::mergeChats(const QString &fromNumbers, const QString toNumbers)
+{
+    QSqlQuery merge(m_database);
+    merge.prepare(SL("UPDATE Messages SET phoneNumber = :toNumbers WHERE phoneNumber = :fromNumbers"));
+    merge.bindValue(SL(":fromNumbers"), fromNumbers);
+    merge.bindValue(SL(":toNumbers"), toNumbers);
+    Database::exec(merge);
+
+    // need to move files to correct chat attachment subdirectory
+    QDir attachments(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + SL("/spacebar/attachments"));
+    const QString folderFromHash = QString::number(qHash(fromNumbers));
+    const QString folderToHash = QString::number(qHash(toNumbers));
+
+    // if folder already exists, just move the files
+    if (attachments.exists(folderToHash) && attachments.exists(folderFromHash)) {
+        const QString folderPathFrom = attachments.path() + QDir::separator() + folderFromHash;
+        const QString folderPathTo = attachments.path() + QDir::separator() + folderToHash;
+        const QStringList files = QDir(folderPathFrom).entryList();
+        for (auto &file : files) {
+            QFile::copy(folderPathFrom + QDir::separator() + file, folderPathTo + QDir::separator() + file);
+            QFile::remove(folderPathFrom + QDir::separator() + file);
+        }
+        attachments.rmdir(folderFromHash);
+    } else if (attachments.exists(folderFromHash)) {
+        attachments.rename(folderFromHash, folderToHash);
+    }
+}
+
 void Database::migrate()
 {
     // Create migration table if necessary
@@ -518,3 +569,34 @@ void Database::migrationV7(uint current)
     sql.prepare(SL("ALTER TABLE Messages ADD COLUMN tapbacks TEXT"));
     Database::exec(sql);
 }
+
+void Database::migrationV8(uint current)
+{
+    MIGRATE_TO(7, current);
+
+    QSqlQuery fetch(m_database);
+    fetch.prepare(SL("SELECT DISTINCT phoneNumber FROM Messages"));
+    exec(fetch);
+
+    while (fetch.next()) {
+        const QString original = fetch.value(0).toString();
+
+        // now using the modem instead of locale to format numbers
+        // fixes any numbers that were not formatted for cases where the locale was unset
+        QString formatted = PhoneNumberList(fetch.value(0).toString().replace(u';', u'~')).toString();
+
+        if (formatted.contains(u'~')) {
+            QStringList numbers = formatted.split(u'~');
+            numbers.sort();
+            formatted = numbers.join(u'~');
+        }
+
+        if (original != formatted) {
+            mergeChats(original, formatted);
+        }
+    }
+
+    QSqlQuery sql(m_database);
+    sql.prepare(SL("UPDATE Messages SET phoneNumber = REPLACE(phoneNumber,';', '~')"));
+    Database::exec(sql);
+}
