@@ -58,10 +58,10 @@ Q_DECLARE_METATYPE(Message)
 
 struct Chat {
     PhoneNumberList phoneNumberList;
-    QDateTime lastContacted;
+    int unreadMessages = 0;
     QString lastMessage;
-    int unreadMessages;
-    bool lastSentByMe;
+    QDateTime lastDateTime;
+    bool lastSentByMe = false;
     QString lastAttachment;
 };
 Q_DECLARE_METATYPE(Chat)
@@ -76,7 +76,7 @@ public:
     // Messages
     void addMessage(const Message &message);
     void deleteMessage(const QString &id);
-    QVector<Message> messagesForNumber(const PhoneNumberList &phoneNumberList, const QString &id = QString(), const bool last = false) const;
+    QVector<Message> messagesForNumber(const PhoneNumberList &phoneNumberList, const QString &id = QString(), const int limit = 0) const;
     void updateMessageDeliveryState(const QString &id, const MessageState state);
     void updateMessageSent(const QString &id, const QString &messageId, const QString &contentLocation);
     void updateMessageDeliveryReport(const QString &messageId);
@@ -87,15 +87,18 @@ public:
     QString lastMessageWithAttachment(const PhoneNumberList &phoneNumberList);
 
     // Chats
-    QVector<Chat> chats() const;
+    QVector<Chat> chats(const PhoneNumberList &phoneNumberList) const;
     int unreadMessagesForNumber(const PhoneNumberList &phoneNumberList) const;
     void markChatAsRead(const PhoneNumberList &phoneNumberList);
     void deleteChat(const PhoneNumberList &phoneNumberList);
+    void mergeChats(const QString &fromNumbers, const QString toNumbers);
 
     static QString generateRandomId();
 
     static void exec(QSqlQuery &query);
 
+    void migrate();
+
 private:
     void migrationV1(uint current);
     void migrationV2(uint current);
@@ -104,10 +107,7 @@ private:
     void migrationV5(uint current);
     void migrationV6(uint current);
     void migrationV7(uint current);
-    void migrate();
+    void migrationV8(uint current);
 
     QSqlDatabase m_database;
-
-Q_SIGNALS:
-    void messagesChanged(const PhoneNumberList &phoneNumberList);
 };
