@@ -5,26 +5,37 @@
 
 #include "channelhandler.h"
 
-#include "utils.h"
 #include "databasethread.h"
-#include "modemcontroller.h"
+
+#include <QLocale>
 
 #include <global.h>
 #include <database.h>
 
-ChannelHandler::ChannelHandler(std::optional<QString> &modemPath, QObject *parent)
+ChannelHandler::ChannelHandler(QObject *parent)
     : QObject(parent)
 {
-    ModemController::instance().init(modemPath);
-
     // daemon dbus interface
     m_interface = new org::kde::spacebar::Daemon(QStringLiteral("org.kde.Spacebar"), QStringLiteral("/Daemon"), QDBusConnection::sessionBus(), this);
 
-    // Refresh chat list when message arrives
-    // The message will be saved by the background daemon
+    const QLocale locale;
+    const QStringList qcountry = locale.name().split(u'_');
+    QString countryCode = qcountry.constLast();
+    PhoneNumber::setCountryCode(countryCode);
+
+    // prefer locale country code, but use modem country code if not set
+    if (countryCode == QStringLiteral("C")) {
+        countryCode = m_interface->countryCode();
+        if (countryCode != SL("The name org.kde.Spacebar was not provided by any .service files")) {
+            PhoneNumber::setCountryCode(countryCode);
+        }
+    }
+
+    // Update the chat list when message arrives
+    // The message is saved to the database by the background daemon
     connect(m_interface, &OrgKdeSpacebarDaemonInterface::messageAdded, [this](const QString &phoneNumber, const QString &id) {
         Q_UNUSED(id);
-        Q_EMIT m_databaseThread.database().messagesChanged(PhoneNumberList(phoneNumber));
+        Q_EMIT messagesChanged(PhoneNumberList(phoneNumber));
     });
 }
 
@@ -37,8 +48,3 @@ org::kde::spacebar::Daemon *ChannelHandler::interface()
 {
     return m_interface;
 }
-
-Mms &ChannelHandler::mms()
-{
-    return m_mms;
-}
