@@ -8,8 +8,6 @@
 
 #include <databasethread.h>
 
-#include <mms.h>
-
 #include "daemoninterface.h"
 
 #include <optional>
@@ -19,18 +17,17 @@ class ChannelHandler : public QObject
     Q_OBJECT
 
 public:
-    explicit ChannelHandler(std::optional<QString> &modemPath, QObject *parent = nullptr);
+    explicit ChannelHandler(QObject *parent = nullptr);
 
     AsyncDatabase &database();
     org::kde::spacebar::Daemon *interface();
-    Mms &mms();
 
 private:
     DatabaseThread m_databaseThread;
     org::kde::spacebar::Daemon *m_interface;
-    Mms m_mms;
 
 Q_SIGNALS:
     void handlerReady();
     void channelOpen(const QString &phoneNumber);
+    void messagesChanged(const PhoneNumberList &phoneNumberList);
 };
