@@ -9,7 +9,7 @@
 #include <QObject>
 #include <QSqlDatabase>
 
-#include <QCoro/Task>
+#include "qcorotask.h"
 
 #include <contactphonenumbermapper.h>
 #include "database.h"
@@ -30,10 +30,11 @@ public:
         DisplayNameRole = Qt::UserRole + 1,
         PhoneNumberListRole,
         UnreadMessagesRole,
-        LastContactedRole,
         LastMessageRole,
+        LastDateTimeRole,
         LastSentByMeRole,
         LastAttachmentRole,
+        LastContactedRole,
         IsContactRole
     };
     Q_ENUM(Role)
@@ -44,16 +45,18 @@ public:
     QVariant data(const QModelIndex &index, int role) const override;
     int rowCount(const QModelIndex &parent = {}) const override;
 
+    Q_INVOKABLE void fetchChatDetails(const PhoneNumberList &phoneNumberList, const bool sort = false);
     Q_INVOKABLE void startChat(const PhoneNumberList &phoneNumberList);
     Q_INVOKABLE void markChatAsRead(const PhoneNumberList &phoneNumberList);
     Q_INVOKABLE void restoreDefaults();
     Q_INVOKABLE void saveSettings();
     Q_INVOKABLE QString attachmentsFolder(const PhoneNumberList &phoneNumberList) const;
+    Q_INVOKABLE void setCharacterLimit(const int &width);
 
     bool ready() const;
 
 public Q_SLOTS:
-    void fetchChats();
+    void fetchChats(const PhoneNumberList &phoneNumberList);
     void deleteChat(const PhoneNumberList &phoneNumberList);
 
 Q_SIGNALS:
@@ -64,10 +67,13 @@ Q_SIGNALS:
     void chatsFetched();
 
 private:
+    QPair<Chat *, int> getChatIndex(const PhoneNumberList &phoneNumberList);
     QCoro::Task<void> fetchChatsInternal();
+    QCoro::Task<void> fetchChatDetailsInternal(const PhoneNumberList &phoneNumberList, const bool sort = false);
 
     ChannelHandler &m_handler;
     QVector<Chat> m_chats;
     ContactPhoneNumberMapper &m_mapper;
     MessageModel *m_messageModel = nullptr;
+    int m_characters = 15;
 };
