@@ -1,6 +1,6 @@
 ﻿// SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #include "databasethread.h"
 
@@ -22,7 +22,7 @@ DatabaseThread::~DatabaseThread()
     wait();
 }
 
-AsyncDatabase *DatabaseThread::database()
+AsyncDatabase &DatabaseThread::database()
 {
-    return &m_database;
+    return m_database;
 }
