@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2020 Jonah Brüchert <jbb@kaidan.im>
 //
-// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
 #pragma once
 
@@ -19,7 +19,7 @@ public:
     explicit DatabaseThread(QObject *parent = nullptr);
     ~DatabaseThread();
 
-    AsyncDatabase *database();
+    AsyncDatabase &database();
 
 private:
     AsyncDatabase m_database;
