@@ -13,7 +13,7 @@
 
 #include "database.h"
 
-#include "qcoro/task.h"
+#include "qcorotask.h"
 
 struct Person {
     Q_GADGET
@@ -31,6 +31,7 @@ class MessageModel : public QAbstractListModel
 {
     Q_OBJECT
     Q_PROPERTY(PhoneNumberList phoneNumberList READ phoneNumberList NOTIFY phoneNumberListChanged)
+    Q_PROPERTY(QString sendingNumber READ sendingNumber CONSTANT)
     Q_PROPERTY(QVector<Person> people READ people NOTIFY peopleChanged)
     Q_PROPERTY(QString attachmentsFolder READ attachmentsFolder CONSTANT)
 
@@ -79,16 +80,13 @@ public:
 
     PhoneNumberList phoneNumberList() const;
 
+    QString sendingNumber() const;
+
     QString attachmentsFolder() const;
 
     Q_INVOKABLE QVariant fileInfo(const QUrl &path);
 
-    /**
-     * @brief Adds a message to the model and the database.
-     * Can be used for example when a new message is received.
-     * @param message
-     */
-    void addMessage(const Message &message);
+    Q_INVOKABLE void fetchAllMessages();
 
     /**
      * @brief adds a tapack reaction to a previously sent or recieved message,
@@ -104,7 +102,7 @@ public:
      * and adds it to the model and database by calling addMessage(const QString&)
      * @param text
      */
-    Q_INVOKABLE void sendMessage(const QString &text, const QStringList &files, const long totalSize);
+    Q_INVOKABLE void sendMessage(const QString &text, const QStringList &files, const qint64 &totalSize);
 
     /**
      * @brief marks a message as read by calling the respective database function
@@ -134,8 +132,6 @@ public:
     Q_INVOKABLE void disableNotifications(const PhoneNumberList &phoneNumberList);
 
 private:
-    QCoro::Task<QString> sendMessageInternal(const PhoneNumber &phoneNumber, const QString &text);
-    QCoro::Task<QString> sendMessageInternalMms(const PhoneNumberList &phoneNumberList, const QString &text, const QStringList &files, const long totalSize);
     QPair<Message *, int> getMessageIndex(const QString &id);
     void updateMessageState(const QString &id, MessageState state, const bool temp = false);
 
@@ -147,7 +143,7 @@ private:
     QVector<Person> m_peopleData;
 
 private Q_SLOTS:
-    QCoro::Task<void> fetchMessages(const QString &id);
+    QCoro::Task<void> fetchMessages(const QString &id, const int limit = 0);
     QCoro::Task<void> fetchUpdatedMessage(const QString &id);
     void messageAdded(const QString &numbers, const QString &id);
     void messageUpdated(const QString &numbers, const QString &id);
@@ -155,4 +151,5 @@ private Q_SLOTS:
 Q_SIGNALS:
     void phoneNumberListChanged();
     void peopleChanged();
+    void messagesFetched();
 };
